==> ngc-3.5.2-en-download.zip: ngc-3.5.2-en/webhelp/ngc-webhelp/navig/contents.js <==
//
//	FindinSite-CD-JS-HelpIndex database outputmanagementguiclient
//
//	Copyright (c) 2016-2025 Software AG, Darmstadt, Germany and/or Software AG USA Inc., Reston, VA, USA
//
var outputmanagementguiclient = {
    baseurls: ["../"],
    varname: "outputmanagementguiclient",
        tree: [
            { url: "about/about.htm", title: "About this Documentation",
              tree: [
                  { url: "about/document_conventions.htm", title: "Document Conventions" },
                  { url: "about/online_information.htm", title: "Online Information and Support" },
                  { url: "about/data_protection.htm", title: "Data Protection" },
              ]
            },
            { url: "cnf/cnf_content_0010.htm", title: "Concepts and Facilities" },
            { url: "rnotes/rnotes-over_0001.htm", title: "Release Notes",
              tree: [
                  { url: "rnotes/rnotes352.htm", title: "Entire Output Management Version 3.5.2 Release Notes" },
                  { url: "rnotes/rnotes351.htm", title: "Entire Output Management Version 3.5.1 Release Notes" },
                  { url: "rnotes/rnotes343.htm", title: "Entire Output Management Version 3.4.3 Release Notes" },
              ]
            },
            { url: "inst/overview.htm", title: "Installation and Customization",
              tree: [
                  { url: "inst/installNGC.htm", title: "Installation of Output Management GUI Client (NGC)" },
              ]
            },
            { url: "ug/ug-over_0001.htm", title: "User's Guide",
              tree: [
                  { url: "ug/MaintenanceFunctions.htm", title: "Maintenance Functions" },
                  { url: "ug/ControlFunctions.htm", title: "Control Functions" },
                  { url: "ug/StartingNGC.htm", title: "Starting the Output Management GUI Client" },
                  { url: "ug/ch_window.htm", title: "Elements of the Main Application Window" },
                  { url: "ug/ug_defr-over_0020.htm", title: "Reports" },
                  { url: "ug/ReportsGenInfo.htm", title: "General Information on Reports" },
                  { url: "ug/ug_defradd_0070.htm", title: "Attributes of a Report" },
                  { url: "ug/ug_defroth_0090.htm", title: "Maintenance Functions for Reports" },
                  { url: "ug/ActiveReports.htm", title: "Active Reports" },
                  { url: "ug/ug_actrpmod_0210.htm", title: "Maintenance Functions for Active Reports" },
                  { url: "ug/ug_defb_0100.htm", title: "Bundles" },
                  { url: "ug/What_is_a_Bundle_Definition.htm", title: "What is a Bundle?" },
                  { url: "ug/ch_bundle_add.htm", title: "Attributes of a Bundle" },
                  { url: "ug/BundleMaintenance.htm", title: "Maintenance Functions for Bundles" },
                  { url: "ug/ug_actbd_0240.htm", title: "Active Bundles" },
                  { url: "ug/ch_abundles_arep.htm", title: "Active Reports in an Active Bundle" },
                  { url: "ug/Folders.htm", title: "Folders" },
                  { url: "ug/ug_print_0110.htm", title: "Logical Printers" },
                  { url: "ug/ug_defl_0120.htm", title: "Distribution Lists" },
                  { url: "ug/ug_auth_0130.htm", title: "Authorizing User Access to Objects" },
                  { url: "ug/ug_prtout_0250.htm", title: "Printouts" },
                  { url: "ug/ch_loginfo.htm", title: "Log Information" },
              ]
            },
            { url: "rm/rm_cmds_0001.htm", title: "Commands" },
            { url: "sysp/sysp-over_0001.htm", title: "System Administration",
              tree: [
                  { url: "sysp/sysp_sysdef_0020.htm", title: "Defaults" },
                  { url: "sysp/sysp_sysuser_0030.htm", title: "Users" },
                  { url: "sysp/sysp_syscal_0050.htm", title: "Calendars" },
                  { url: "sysp/sysp_sysprin_0060.htm", title: "Physical Printers" },
                  { url: "sysp/PhysicalPrinterAttributes.htm", title: "Attributes of Physical Printers" },
                  { url: "sysp/PhysicalPrinterMaintenance.htm", title: "Maintenance Functions for Physical Printers" },
                  { url: "sysp/PhysicalPrinterSpecial.htm", title: "Special Printer Types" },
                  { url: "sysp/sysp_sysmon_0070.htm", title: "Monitor Management" },
                  { url: "sysp/TaskManagement.htm", title: "Task Management" },
                  { url: "sysp/sysp_arch_0130.htm", title: "Archive Administration" },
                  { url: "sysp/Separator_Pages.htm", title: "Separator Pages" },
                  { url: "sysp/Us_Sep_Rout.htm", title: "User Separation Routines" },
                  { url: "sysp/PrinterExits.htm", title: "Printer Exits" },
                  { url: "sysp/APIs.htm", title: "Application Programming Interfaces" },
                  { url: "sysp/binarydocuments.htm", title: "Setting Up Environments for Binary Documents" },
                  { url: "sysp/sysp_trs_0150.htm", title: "Transferring Objects" },
                  { url: "sysp/TransferEnvironment.htm", title: "Transferring the Whole Environment" },
                  { url: "sysp/NOMVPRNTmanagement.htm", title: "VTAM NOMVPRNT Management" },
                  { url: "sysp/AdabasVista.htm", title: "Using Adabas Vista" },
              ]
            },
            { url: "general/legal.htm", title: "Copyright" },
        ]
};

var mainProject = 1;

$.event.trigger({ type: "fishidbloaded", db: outputmanagementguiclient });

==> ngc-3.5.3-en-download.zip: ngc-3.5.3-en/webhelp/ngc-webhelp/navig/contents.js <==
//
//	FindinSite-CD-JS-HelpIndex database outputmanagementguiclient
//
//	Copyright (c) 2016-2025 Software AG, Darmstadt, Germany and/or Software AG USA Inc., Reston, VA, USA
//
var outputmanagementguiclient = {
    baseurls: ["../"],
    varname: "outputmanagementguiclient",
        tree: [
            { url: "about/about.htm", title: "About this Documentation",
              tree: [
                  { url: "about/document_conventions.htm", title: "Document Conventions" },
                  { url: "about/online_information.htm", title: "Online Information and Support" },
                  { url: "about/data_protection.htm", title: "Data Protection" },
              ]
            },
            { url: "cnf/cnf_content_0010.htm", title: "Concepts and Facilities" },
            { url: "rnotes/rnotes-over_0001.htm", title: "Entire Output Management Version 3.5.3 Release Notes" },
            { url: "inst/overview.htm", title: "Installation and Customization",
              tree: [
                  { url: "inst/installNGC.htm", title: "Installation of Output Management GUI Client (NGC)" },
              ]
            },
            { url: "ug/ug-over_0001.htm", title: "User's Guide",
              tree: [
                  { url: "ug/MaintenanceFunctions.htm", title: "Maintenance Functions" },
                  { url: "ug/ControlFunctions.htm", title: "Control Functions" },
                  { url: "ug/StartingNGC.htm", title: "Starting the Output Management GUI Client" },
                  { url: "ug/ch_window.htm", title: "Elements of the Main Application Window" },
                  { url: "ug/ug_defr-over_0020.htm", title: "Reports" },
                  { url: "ug/ReportsGenInfo.htm", title: "General Information on Reports" },
                  { url: "ug/ug_defradd_0070.htm", title: "Attributes of a Report" },
                  { url: "ug/ug_defroth_0090.htm", title: "Maintenance Functions for Reports" },
                  { url: "ug/ActiveReports.htm", title: "Active Reports" },
                  { url: "ug/ug_actrpmod_0210.htm", title: "Maintenance Functions for Active Reports" },
                  { url: "ug/ug_defb_0100.htm", title: "Bundles" },
                  { url: "ug/What_is_a_Bundle_Definition.htm", title: "What is a Bundle?" },
                  { url: "ug/ch_bundle_add.htm", title: "Attributes of a Bundle" },
                  { url: "ug/BundleMaintenance.htm", title: "Maintenance Functions for Bundles" },
                  { url: "ug/ug_actbd_0240.htm", title: "Active Bundles" },
                  { url: "ug/ch_abundles_arep.htm", title: "Active Reports in an Active Bundle" },
                  { url: "ug/Folders.htm", title: "Folders" },
                  { url: "ug/ug_print_0110.htm", title: "Logical Printers" },
                  { url: "ug/ug_defl_0120.htm", title: "Distribution Lists" },
                  { url: "ug/ug_auth_0130.htm", title: "Authorizing User Access to Objects" },
                  { url: "ug/ug_prtout_0250.htm", title: "Printouts" },
                  { url: "ug/ch_loginfo.htm", title: "Log Information" },
              ]
            },
            { url: "rm/rm_cmds_0001.htm", title: "Commands" },
            { url: "sysp/sysp-over_0001.htm", title: "System Administration",
              tree: [
                  { url: "sysp/sysp_sysdef_0020.htm", title: "Defaults" },
                  { url: "sysp/sysp_sysuser_0030.htm", title: "Users" },
                  { url: "sysp/sysp_syscal_0050.htm", title: "Calendars" },
                  { url: "sysp/sysp_sysprin_0060.htm", title: "Physical Printers" },
                  { url: "sysp/PhysicalPrinterAttributes.htm", title: "Attributes of Physical Printers" },
                  { url: "sysp/PhysicalPrinterMaintenance.htm", title: "Maintenance Functions for Physical Printers" },
                  { url: "sysp/PhysicalPrinterSpecial.htm", title: "Special Printer Types" },
                  { url: "sysp/sysp_sysmon_0070.htm", title: "Monitor Management" },
                  { url: "sysp/TaskManagement.htm", title: "Task Management" },
                  { url: "sysp/sysp_arch_0130.htm", title: "Archive Administration" },
                  { url: "sysp/Separator_Pages.htm", title: "Separator Pages" },
                  { url: "sysp/Us_Sep_Rout.htm", title: "User Separation Routines" },
                  { url: "sysp/PrinterExits.htm", title: "Printer Exits" },
                  { url: "sysp/APIs.htm", title: "Application Programming Interfaces" },
                  { url: "sysp/binarydocuments.htm", title: "Setting Up Environments for Binary Documents" },
                  { url: "sysp/sysp_trs_0150.htm", title: "Transferring Objects" },
                  { url: "sysp/TransferEnvironment.htm", title: "Transferring the Whole Environment" },
                  { url: "sysp/NOMVPRNTmanagement.htm", title: "VTAM NOMVPRNT Management" },
                  { url: "sysp/AdabasVista.htm", title: "Using Adabas Vista" },
              ]
            },
            { url: "general/legal.htm", title: "Copyright" },
        ]
};

var mainProject = 1;

$.event.trigger({ type: "fishidbloaded", db: outputmanagementguiclient });
